<?php
/**
 * Module Name: Carousel
 * Module Description: Display images and galleries in a gorgeous, full-screen browsing experience
 * Sort Order: 22
 * Recommendation Order: 12
 * First Introduced: 1.5
 * Requires Connection: No
 * Auto Activate: No
 * Module Tags: Photos and Videos
 * Feature: Appearance
 * Additional Search Queries: gallery, carousel, diaporama, slideshow, images, lightbox, exif, metadata, image, creator
 *
 * @package automattic/jetpack
 */

/**
 * Require the jetpack-carousel module code
 */
require __DIR__ . '/carousel/jetpack-carousel.php';
